@@ -1103,7 +1103,7 @@ class TestTrajectory:
         line = LineString([(2, 4), (3, 4)])
         assert traj.distance(line, units="km") == 0.001
 
-    def test_distance_warning(self):
+    def test_euclidean_distance_warning(self):
         with pytest.warns(UserWarning):
             point = Point(0, 0)
             self.default_traj_latlon.distance(point)
@@ -1142,3 +1142,40 @@ class TestTrajectory:
         new_df = traj.df.to_crs(epsg=3857)
         self.assertEqual(new_df.crs, from_epsg(3857))
     """
+
+
+class TestTrajectoryNonGeo:
+    def setup_method(self):
+        n = 3
+        start = datetime(2023, 1, 1)
+        data = {
+            "t": [start + timedelta(seconds=i) for i in range(n)],
+            "x": [0, 1, 2],
+            "y": [0, 0, 0],
+        }
+        df = pd.DataFrame(data)
+        self.traj_xyt = Trajectory(df, traj_id=1, t="t", x="x", y="y", crs=CRS_METRIC)
+
+        data = {
+            "a": [start + timedelta(seconds=i) for i in range(n)],
+            "b": [0, 1, 2],
+            "c": [0, 0, 0],
+        }
+        df = pd.DataFrame(data)
+        self.traj_abc = Trajectory(df, traj_id=1, t="a", x="b", y="c", crs=CRS_METRIC)
+
+    def test_get_length_nongeo_df(self):
+        assert self.traj_xyt.get_length() == 2
+        assert self.traj_abc.get_length() == 2
+
+    def test_start_location_nongeo(self):
+        assert self.traj_xyt.get_start_location() == Point(0, 0)
+        assert self.traj_abc.get_start_location() == Point(0, 0)
+
+    def test_traj_copy_custom_col(self):
+        traj_0 = self.traj_abc
+        traj = traj_0.copy()
+        assert traj.x == traj_0.x
+        assert traj.y == traj_0.y
+        traj.add_speed()
+        traj.add_direction()
