@@ -44,7 +44,9 @@ class TestTrajectoryCollection:
             columns=["id", "obj", "geometry", "t", "val", "val2"],
         ).set_index("t")
         self.geo_df = GeoDataFrame(df, crs=CRS_METRIC)
-        self.collection = TrajectoryCollection(self.geo_df, "id", obj_id_col="obj")
+        self.collection = TrajectoryCollection(
+            self.geo_df, traj_id_col="id", obj_id_col="obj"
+        )
         self.geo_df_latlon = GeoDataFrame(df).set_crs(
             crs=CRS_LATLON, allow_override=True
         )
@@ -384,11 +386,11 @@ class TestTrajectoryCollection:
         assert result1[0] == pytest.approx(0.01667, 0.001)
         assert len(result0) == 4
 
-    def test_add_speed_multithreaded(self):
+    def test_add_speed_multiprocessing(self):
         self.collection.trajectories += self.collection.trajectories
         expected = self.collection.copy()
         expected.add_speed()
-        self.collection.add_speed(n_threads=2)
+        self.collection.add_speed(n_processes=2)
         print(self.collection.to_point_gdf())
         result0 = self.collection.trajectories[0].df[SPEED_COL_NAME].tolist()
         assert result0 == expected.trajectories[0].df[SPEED_COL_NAME].tolist()
@@ -402,11 +404,11 @@ class TestTrajectoryCollection:
         result1 = self.collection.trajectories[0].df[ACCELERATION_COL_NAME].tolist()
         assert len(result1) == 4
 
-    def test_add_acceleration_multithreaded(self):
+    def test_add_acceleration_multiprocessing(self):
         expected = self.collection.copy()
         expected.add_acceleration()
         print(expected.to_point_gdf())
-        self.collection.add_acceleration(n_threads=2)
+        self.collection.add_acceleration(n_processes=2)
         print(self.collection.to_point_gdf())
         result0 = self.collection.trajectories[0].df[ACCELERATION_COL_NAME].tolist()
         assert result0 == expected.trajectories[0].df[ACCELERATION_COL_NAME].tolist()
@@ -418,11 +420,11 @@ class TestTrajectoryCollection:
         result = self.collection.trajectories[0].df[DIRECTION_COL_NAME].tolist()
         assert len(result) == 4
 
-    def test_add_direction_multithreaded(self):
+    def test_add_direction_multiprocessing(self):
         expected = self.collection.copy()
         expected.add_direction()
         print(expected.to_point_gdf())
-        self.collection.add_direction(n_threads=2)
+        self.collection.add_direction(n_processes=2)
         print(self.collection.to_point_gdf())
         result0 = self.collection.trajectories[0].df[DIRECTION_COL_NAME].tolist()
         assert result0 == expected.trajectories[0].df[DIRECTION_COL_NAME].tolist()
@@ -434,11 +436,11 @@ class TestTrajectoryCollection:
         result0 = self.collection.trajectories[0].df[DISTANCE_COL_NAME].tolist()
         assert len(result0) == 4
 
-    def test_add_distance_multithreaded(self):
+    def test_add_distance_multiprocessing(self):
         expected = self.collection.copy()
         expected.add_distance()
         print(expected.to_point_gdf())
-        self.collection.add_distance(n_threads=2)
+        self.collection.add_distance(n_processes=2)
         print(self.collection.to_point_gdf())
         result0 = self.collection.trajectories[0].df[DISTANCE_COL_NAME].tolist()
         assert result0 == expected.trajectories[0].df[DISTANCE_COL_NAME].tolist()
@@ -452,11 +454,11 @@ class TestTrajectoryCollection:
         )
         assert len(result1) == 4
 
-    def test_add_angular_difference_multithreaded(self):
+    def test_add_angular_difference_multiprocessing(self):
         expected = self.collection.copy()
         expected.add_angular_difference()
         print(expected.to_point_gdf())
-        self.collection.add_angular_difference(n_threads=2)
+        self.collection.add_angular_difference(n_processes=2)
         print(self.collection.to_point_gdf())
         result0 = (
             self.collection.trajectories[0].df[ANGULAR_DIFFERENCE_COL_NAME].tolist()
@@ -476,11 +478,11 @@ class TestTrajectoryCollection:
         result1 = self.collection.trajectories[0].df[TIMEDELTA_COL_NAME].tolist()
         assert len(result1) == 4
 
-    def test_add_timedelta_multithreaded(self):
+    def test_add_timedelta_multiprocessing(self):
         expected = self.collection.copy()
         expected.add_timedelta()
         print(expected.to_point_gdf())
-        self.collection.add_timedelta(n_threads=2)
+        self.collection.add_timedelta(n_processes=2)
         print(self.collection.to_point_gdf())
         result0 = self.collection.trajectories[0].df[TIMEDELTA_COL_NAME].tolist()
         assert result0 == expected.trajectories[0].df[TIMEDELTA_COL_NAME].tolist()
@@ -603,3 +605,61 @@ class TestTrajectoryCollection:
             str(json)
             == """{'type': 'FeatureCollection', 'features': [{'type': 'Feature', 'properties': {'id': 1, 'obj': 'A', 'val': 9, 'val2': 'a'}, 'temporalGeometry': {'type': 'MovingPoint', 'coordinates': [(0.0, 0.0), (6.0, 0.0), (6.0, 6.0), (9.0, 9.0)], 'datetimes': [Timestamp('2018-01-01 12:00:00'), Timestamp('2018-01-01 12:06:00'), Timestamp('2018-01-01 14:10:00'), Timestamp('2018-01-01 14:15:00')]}}, {'type': 'Feature', 'properties': {'id': 2, 'obj': 'A', 'val': 10, 'val2': 'e'}, 'temporalGeometry': {'type': 'MovingPoint', 'coordinates': [(10.0, 10.0), (16.0, 10.0), (16.0, 16.0), (190.0, 10.0)], 'datetimes': [Timestamp('2018-01-01 12:00:00'), Timestamp('2018-01-01 12:06:00'), Timestamp('2018-01-02 13:10:00'), Timestamp('2018-01-02 13:15:00')]}}]}"""  # noqa F401
         )
+
+    def test_deprecation_warning_when_using_n_threads(self):
+        with pytest.deprecated_call():
+            self.collection.add_speed(n_threads=2)
+
+
+class TestTrajectoryCollectionNonGeo:
+    def setup_method(self):
+        df = pd.DataFrame(
+            [
+                [1, "A", Point(0, 0), datetime(2018, 1, 1, 12, 0, 0), 9, "a"],
+                [1, "A", Point(6, 0), datetime(2018, 1, 1, 12, 6, 0), 5, "b"],
+                [1, "A", Point(6, 6), datetime(2018, 1, 1, 14, 10, 0), 2, "c"],
+                [1, "A", Point(9, 9), datetime(2018, 1, 1, 14, 15, 0), 4, "d"],
+                [2, "A", Point(10, 10), datetime(2018, 1, 1, 12, 0, 0), 10, "e"],
+                [2, "A", Point(16, 10), datetime(2018, 1, 1, 12, 6, 0), 6, "f"],
+                [2, "A", Point(16, 16), datetime(2018, 1, 2, 13, 10, 0), 7, "g"],
+                [2, "A", Point(190, 10), datetime(2018, 1, 2, 13, 15, 0), 3, "h"],
+            ],
+            columns=["id", "obj", "geometry", "t", "val", "val2"],
+        ).set_index("t")
+        self.geo_df = GeoDataFrame(df, crs=CRS_METRIC)
+        df = pd.DataFrame(self.geo_df)
+        df["x"] = self.geo_df.geometry.x
+        df["y"] = self.geo_df.geometry.y
+        df = df.drop(columns="geometry")
+        self.collection = TrajectoryCollection(
+            df, traj_id_col="id", obj_id_col="obj", x="x", y="y", crs=CRS_METRIC
+        )
+
+    def test_number_of_trajectories_nongeo(self):
+        assert len(self.collection) == 2
+
+    def test_get_start_locations_nongeo(self):
+        locs = self.collection.get_start_locations()
+        assert len(locs) == 2
+        assert locs.iloc[0].geometry in [Point(0, 0), Point(10, 10)]
+        assert locs.iloc[0].id in [1, 2]
+        assert locs.iloc[0].obj == "A"
+        assert locs.iloc[0].val in [9, 10]
+        assert locs.iloc[0].val2 in ["a", "e"]
+        assert locs.iloc[1].geometry in [Point(0, 0), Point(10, 10)]
+        assert locs.iloc[0].geometry != locs.iloc[1].geometry
+        assert isinstance(locs, GeoDataFrame)
+        assert locs.crs == CRS_METRIC
+
+    def test_get_end_locations_nongeo(self):
+        locs = self.collection.get_end_locations()
+        assert len(locs) == 2
+        assert locs.iloc[0].geometry in [Point(9, 9), Point(190, 10)]
+        assert locs.iloc[0].id in [1, 2]
+        assert locs.iloc[0].obj == "A"
+        assert locs.iloc[0].val in [4, 3]
+        assert locs.iloc[0].val2 in ["d", "h"]
+        assert locs.iloc[1].geometry in [Point(9, 9), Point(190, 10)]
+        assert locs.iloc[0].geometry != locs.iloc[1].geometry
+        assert isinstance(locs, GeoDataFrame)
+        assert locs.crs == CRS_METRIC
