@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import numpy as np
-import pandas as pd
+from pandas import DataFrame
 from datetime import datetime
 from pyproj import CRS
 from geopandas import GeoDataFrame
@@ -19,7 +19,7 @@ CRS_LATLON = CRS.from_user_input(4326)
 
 class TestTrajectorySmoother:
     def setup_method(self):
-        df = pd.DataFrame(
+        df = DataFrame(
             [
                 [1, "A", Point(0, 0), datetime(2018, 1, 1, 12, 0, 0)],
                 [1, "A", Point(6, 0), datetime(2018, 1, 1, 12, 6, 0)],
@@ -138,3 +138,54 @@ class TestTrajectorySmoother:
         assert len(collection) == 2
         assert np.allclose(collection.trajectories[0].to_linestring().xy, truth_1.xy)
         assert np.allclose(collection.trajectories[1].to_linestring().xy, truth_2.xy)
+
+
+class TestTrajectorySmootherNonGeo:
+    def setup_method(self):
+        df = DataFrame(
+            [
+                [1, "A", Point(0, 0), datetime(2018, 1, 1, 12, 0, 0)],
+                [1, "A", Point(6, 0), datetime(2018, 1, 1, 12, 6, 0)],
+                [1, "A", Point(6, 6), datetime(2018, 1, 1, 14, 10, 0)],
+                [1, "A", Point(9, 9), datetime(2018, 1, 1, 14, 15, 0)],
+                [2, "A", Point(10, 10), datetime(2018, 1, 1, 12, 0, 0)],
+                [2, "A", Point(16, 10), datetime(2018, 1, 1, 12, 6, 0)],
+                [2, "A", Point(16, 16), datetime(2018, 1, 2, 13, 10, 0)],
+                [2, "A", Point(190, 19), datetime(2018, 1, 2, 13, 15, 0)],
+            ],
+            columns=["id", "obj", "geometry", "t"],
+        ).set_index("t")
+        gdf = GeoDataFrame(df, crs=CRS_METRIC)
+        gdf["x"] = gdf.geometry.x
+        gdf["y"] = gdf.geometry.y
+        df = DataFrame(gdf)
+        df = df.drop(columns=["geometry"])
+        print(df)
+        self.collection = TrajectoryCollection(
+            df, "id", obj_id_col="obj", x="x", y="y", crs=CRS_METRIC
+        )
+
+    @requires_stonesoup
+    def test_kalman_smoother_sv_collection(self):
+        from movingpandas.trajectory_smoother import KalmanSmootherCV
+
+        collection = KalmanSmootherCV(self.collection).smooth(
+            process_noise_std=0.1, measurement_noise_std=10
+        )
+        truth_1 = loads(
+            "LINESTRING ("
+            "0.0044805333934456 0.0000761144223231, "
+            "5.9954842501546315 -0.0000845436868686, "
+            "6.00040594977978 6.000156500844182, "
+            "8.999629266671697 8.999851928420188)"
+        )
+        truth_2 = loads(
+            "LINESTRING ("
+            "10.004429320057262 10.000008962523324, "
+            "15.995566251010434 9.999990965241574, "
+            "16.000875056273347 16.000014621277007, "
+            "189.9991293726476 18.99998545095791)"
+        )
+        assert len(collection) == 2
+        assert np.allclose(collection.trajectories[0].to_linestring().xy, truth_1.xy)
+        assert np.allclose(collection.trajectories[1].to_linestring().xy, truth_2.xy)
