@@ -78,6 +78,8 @@ class MinDistanceGeneralizer(TrajectoryGeneralizer):
     """
 
     def _generalize_traj(self, traj, tolerance):
+        if traj.df.geometry.isnull().all():
+            traj.populate_geometry_column()
         temp_df = traj.df.copy()
         prev_pt = temp_df.iloc[0][traj.get_geom_col()]
         keep_rows = [0]
@@ -124,7 +126,9 @@ class MinTimeDeltaGeneralizer(TrajectoryGeneralizer):
 
         keep_rows.append(len(traj.df) - 1)
         new_df = traj.df.iloc[keep_rows]
-        new_traj = Trajectory(new_df, traj.id, traj_id_col=traj.get_traj_id_col())
+        new_traj = Trajectory(
+            new_df, traj.id, traj_id_col=traj.get_traj_id_col(), x=traj.x, y=traj.y
+        )
         return new_traj
 
 
@@ -188,6 +192,9 @@ class DouglasPeuckerGeneralizer(TrajectoryGeneralizer):
     """
 
     def _generalize_traj(self, traj, tolerance):
+        if traj.df.geometry.isnull().all():
+            traj.populate_geometry_column()
+
         keep_rows = []
         simplified = (
             traj.to_linestring().simplify(tolerance, preserve_topology=False).coords
@@ -229,6 +236,8 @@ class TopDownTimeRatioGeneralizer(TrajectoryGeneralizer):
     """
 
     def _generalize_traj(self, traj, tolerance):
+        if traj.df.geometry.isnull().all():
+            traj.populate_geometry_column()
         generalized = self.td_tr(traj.df.copy(), tolerance)
         return Trajectory(generalized, traj.id, traj_id_col=traj.get_traj_id_col())
 
