@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
 from copy import copy
+from functools import partial
+from multiprocessing import Pool
 from pandas import Grouper
 from geopandas import GeoDataFrame
 import numpy as np
@@ -29,12 +31,19 @@ class TrajectorySplitter:
         """
         self.traj = traj
 
-    def split(self, **kwargs):
+    def split(self, n_processes=1, **kwargs):
         """
         Split the input Trajectory/TrajectoryCollection.
 
         Parameters
         ----------
+        n_processes : int or None, optional
+            Number of processes to use for computation when splitting on a
+            `TrajectoryCollection` (default: 1). If set to `None`,
+            the number of processes will be set to `os.cpu_count()`
+            (or `os.process_cpu_count()` in Python 3.13+), enabling full CPU
+            utilization via multiprocessing. This argument will be ignored when used
+            with a `Trajectory` object.
         kwargs : any type
             Split parameters, differs by splitter
 
@@ -46,13 +55,19 @@ class TrajectorySplitter:
         if isinstance(self.traj, Trajectory):
             return self._split_traj(self.traj, **kwargs)
         elif isinstance(self.traj, TrajectoryCollection):
-            return self._split_traj_collection(**kwargs)
+            if n_processes > 1 or n_processes is None:
+                return self._split_traj_collection_multiprocessing(
+                    n_processes, **kwargs
+                )
+            else:
+                return self._split_traj_collection(self.traj, **kwargs)
         else:
             raise TypeError
 
-    def _split_traj_collection(self, **kwargs):
+    def _split_traj_collection(self, trajs, **kwargs):
         trips = []
-        for traj in self.traj:
+
+        for traj in trajs:
             for x in self._split_traj(traj, **kwargs):
                 if x.get_length() > self.traj.min_length:
                     trips.append(x)
@@ -60,6 +75,25 @@ class TrajectorySplitter:
         result.trajectories = trips
         return result
 
+    def _split_traj_collection_multiprocessing(self, n_processes, **kwargs):
+        from movingpandas.tools._multi_threading import split_list
+
+        p = Pool(n_processes)
+        data = split_list(self.traj.trajectories, n_processes)
+        data = [d for d in data]
+
+        split_traj_collection_with_kwargs = partial(
+            self._split_traj_collection, **kwargs
+        )
+
+        splits = []
+        for split in p.map(split_traj_collection_with_kwargs, data):
+            splits.extend(split)
+
+        result = copy(self.traj)
+        result.trajectories = splits
+        return result
+
     def _split_traj(self, traj, **kwargs):
         return traj
 
@@ -109,7 +143,13 @@ class TemporalSplitter(TrajectorySplitter):
                 df = df.sort_index(ascending=True)
             if len(df) > 1:
                 result.append(
-                    Trajectory(df, f"{traj.id}_{i}", traj_id_col=traj.get_traj_id_col())
+                    Trajectory(
+                        df,
+                        f"{traj.id}_{i}",
+                        traj_id_col=traj.get_traj_id_col(),
+                        x=traj.x,
+                        y=traj.y,
+                    )
                 )
         return TrajectoryCollection(result, min_length=min_length)
 
@@ -144,7 +184,13 @@ class ObservationGapSplitter(TrajectorySplitter):
             df = df.drop(columns=["t", "gap"])
             if len(df) > 1:
                 result.append(
-                    Trajectory(df, f"{traj.id}_{i}", traj_id_col=traj.get_traj_id_col())
+                    Trajectory(
+                        df,
+                        f"{traj.id}_{i}",
+                        traj_id_col=traj.get_traj_id_col(),
+                        x=traj.x,
+                        y=traj.y,
+                    )
                 )
         return TrajectoryCollection(result, min_length=min_length)
 
@@ -288,7 +334,13 @@ class AngleChangeSplitter(TrajectorySplitter):
                     df = df.sort_index(ascending=True)
 
                 result.append(
-                    Trajectory(df, f"{traj.id}_{i}", traj_id_col=traj.get_traj_id_col())
+                    Trajectory(
+                        df,
+                        f"{traj.id}_{i}",
+                        traj_id_col=traj.get_traj_id_col(),
+                        x=traj.x,
+                        y=traj.y,
+                    )
                 )
 
         return TrajectoryCollection(result, min_length=min_length)
@@ -330,8 +382,13 @@ class ValueChangeSplitter(TrajectorySplitter):
                 df = df.sort_index(ascending=True)
             if len(df) > 1:
                 df = GeoDataFrame(df).set_crs(traj.df.crs)
-                traj = Trajectory(
-                    df, f"{traj.id}_{i}", traj_id_col=traj.get_traj_id_col()
+                result.append(
+                    Trajectory(
+                        df,
+                        f"{traj.id}_{i}",
+                        traj_id_col=traj.get_traj_id_col(),
+                        x=traj.x,
+                        y=traj.y,
+                    )
                 )
-                result.append(traj)
         return TrajectoryCollection(result, min_length=min_length)
